@@ -140,6 +140,63 @@ impl GeneralReadout for LinuxGeneralReadout {
         }
     }
 
+    fn resolution(&self) -> Result<String, ReadoutError> {
+        use std::os::raw::c_char;
+        use x11::xlib::XCloseDisplay;
+        use x11::xlib::XDefaultScreen;
+        use x11::xlib::XDisplayHeight;
+        use x11::xlib::XDisplayWidth;
+        use x11::xlib::XOpenDisplay;
+
+        let display_name: *const c_char = std::ptr::null_mut();
+
+        let display = unsafe { XOpenDisplay(display_name) };
+        if !display.is_null() {
+            let screen = unsafe { XDefaultScreen(display) };
+            let width = unsafe { XDisplayWidth(display, screen) };
+            let height = unsafe { XDisplayHeight(display, screen) };
+
+            unsafe { XCloseDisplay(display) };
+            unsafe {
+                libc::free(display_name as *mut libc::c_void);
+            }
+
+            return Ok(format!("{}x{}", width, height));
+        } else {
+            let drm = std::path::Path::new("/sys/class/drm");
+            if drm.is_dir() {
+                let dirs = extra::list_dir_entries(drm);
+                let mut resolution = String::new();
+                for entry in dirs {
+                    if entry.read_link().is_ok() {
+                        let modes = std::path::PathBuf::from(entry).join("modes");
+                        if modes.is_file() {
+                            if let Ok(mut this_res) = std::fs::read_to_string(modes) {
+                                if this_res.is_empty() {
+                                    if this_res.ends_with("\n") {
+                                        this_res.pop();
+                                    }
+                                    resolution.push_str(&this_res);
+                                    resolution.push_str(", ");
+                                }
+                            }
+                        }
+                    }
+                }
+
+                if resolution.trim_end().ends_with(",") {
+                    resolution.pop();
+                }
+
+                return Ok(resolution);
+            }
+        }
+
+        Err(ReadoutError::Other(String::from(
+            "Could not obtain screen resolution.",
+        )))
+    }
+
     fn machine(&self) -> Result<String, ReadoutError> {
         let product_readout = LinuxProductReadout::new();
 
@@ -316,7 +373,7 @@ impl MemoryReadout for LinuxMemoryReadout {
         let info_ptr: *mut sysinfo = &mut info;
         let ret = unsafe { sysinfo(info_ptr) };
         if ret != -1 {
-            Ok(info.totalram * info.mem_unit as u64 / 1024)
+            Ok(info.totalram as u64 * info.mem_unit as u64 / 1024)
         } else {
             Err(ReadoutError::Other(
                 "Failed to get system statistics".to_string(),
@@ -329,7 +386,7 @@ impl MemoryReadout for LinuxMemoryReadout {
         let info_ptr: *mut sysinfo = &mut info;
         let ret = unsafe { sysinfo(info_ptr) };
         if ret != -1 {
-            Ok(info.freeram * info.mem_unit as u64 / 1024)
+            Ok(info.freeram as u64 * info.mem_unit as u64 / 1024)
         } else {
             Err(ReadoutError::Other(
                 "Failed to get system statistics".to_string(),
@@ -342,7 +399,7 @@ impl MemoryReadout for LinuxMemoryReadout {
         let info_ptr: *mut sysinfo = &mut info;
         let ret = unsafe { sysinfo(info_ptr) };
         if ret != -1 {
-            Ok(info.bufferram * info.mem_unit as u64 / 1024)
+            Ok(info.bufferram as u64 * info.mem_unit as u64 / 1024)
         } else {
             Err(ReadoutError::Other(
                 "Failed to get system statistics".to_string(),
